DynamicPinKeyboard class

Inheritance

Constructors

DynamicPinKeyboard({required dynamic numberOne(String), required dynamic numberTwo(String), required dynamic numberThree(String), required dynamic numberFour(String), required dynamic numberFive(String), required dynamic numberSix(String), required dynamic numberSeven(String), required dynamic numberEight(String), required dynamic numberNine(String), required dynamic numberZero(String), required VoidCallback? removePin, Color? numberBodyColour, Color? numberBorderColor, bool biometric = false, VoidCallback? biometricAction, TextStyle? textStyle, Widget? removePinIcon, Widget? biometricIcon, double? borderwidth, Key? key})
const

Properties

biometric bool
final
biometricAction VoidCallback?
final
biometricIcon Widget?
final
borderwidth double?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
numberBodyColour Color?
final
numberBorderColor Color?
final
numberEight → dynamic Function(String)
final
numberFive → dynamic Function(String)
final
numberFour → dynamic Function(String)
final
numberNine → dynamic Function(String)
final
numberOne → dynamic Function(String)
final
numberSeven → dynamic Function(String)
final
numberSix → dynamic Function(String)
final
numberThree → dynamic Function(String)
final
numberTwo → dynamic Function(String)
final
numberZero → dynamic Function(String)
final
removePin VoidCallback?
final
removePinIcon Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<DynamicPinKeyboard>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited